==> amps-java-client-5.3.0.1.tar.gz: amps-java-client-5.3.0.1/src/com/crankuptheamps/client/JSONProtocol.java <==
////////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2010-2019 60East Technologies Inc., All Rights Reserved.
//
// This computer software is owned by 60East Technologies Inc. and is
// protected by U.S. copyright laws and other laws and by international
// treaties.  This computer software is furnished by 60East Technologies
// Inc. pursuant to a written license agreement and may be used, copied,
// transmitted, and stored only in accordance with the terms of such
// license agreement and with the inclusion of the above copyright notice.
// This computer software or any other copies thereof may not be provided
// or otherwise made available to any other person.
//
// U.S. Government Restricted Rights.  This computer software: (a) was
// developed at private expense and is in all respects the proprietary
// information of 60East Technologies Inc.; (b) was not developed with
// government funds; (c) is a trade secret of 60East Technologies Inc.
// for all purposes of the Freedom of Information Act; and (d) is a
// commercial item and thus, pursuant to Section 12.212 of the Federal
// Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
// Government's use, duplication or disclosure of the computer software
// is subject to the restrictions set forth by 60East Technologies Inc..
//
////////////////////////////////////////////////////////////////////////////
package com.crankuptheamps.client;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.Properties;

/**
 * Implements the Protocol interface. Used to parse a byte stream using JSON protocol (the "amps" transport protocol). 
 */

public class JSONProtocol implements Protocol {

    public JSONProtocol()
    {
    }

    public JSONProtocol(Properties props)
    {
    }

    /**
     * Allocates a new JSON Message. 
     * @return Newly allocated JSON Message.
     */
    public JSONMessage allocateMessage()
    {
        return new JSONMessage(StandardCharsets.UTF_8.newEncoder(),
                StandardCharsets.UTF_8.newDecoder());
    }


    public JSONProtocolParser getMessageStream()
    {
        return new JSONProtocolParser(this);
    }

}

==> amps-java-client-5.3.4.1.tar.gz: amps-java-client-5.3.4.1/src/com/crankuptheamps/client/JSONProtocol.java <==
////////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2010-2025 60East Technologies Inc., All Rights Reserved.
//
// This computer software is owned by 60East Technologies Inc. and is
// protected by U.S. copyright laws and other laws and by international
// treaties.  This computer software is furnished by 60East Technologies
// Inc. pursuant to a written license agreement and may be used, copied,
// transmitted, and stored only in accordance with the terms of such
// license agreement and with the inclusion of the above copyright notice.
// This computer software or any other copies thereof may not be provided
// or otherwise made available to any other person.
//
// U.S. Government Restricted Rights.  This computer software: (a) was
// developed at private expense and is in all respects the proprietary
// information of 60East Technologies Inc.; (b) was not developed with
// government funds; (c) is a trade secret of 60East Technologies Inc.
// for all purposes of the Freedom of Information Act; and (d) is a
// commercial item and thus, pursuant to Section 12.212 of the Federal
// Acquisition Regulations (FAR) and DFAR Supplement Section 227.7202,
// Government's use, duplication or disclosure of the computer software
// is subject to the restrictions set forth by 60East Technologies Inc..
//
////////////////////////////////////////////////////////////////////////////
package com.crankuptheamps.client;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;
import java.util.Properties;

/**
 * Implements the Protocol interface. Used to parse a byte stream using
 * JSON protocol (the "amps" transport protocol).
 */
public class JSONProtocol implements Protocol {

    /**
     * Initializes a new instance of the JSONProtocol class.
     */
    public JSONProtocol()
    {
    }

    /**
     * Initializes a new instance of the JSONProtocol class with
     * the specified properties.
     * @param props The properties.
     */
    public JSONProtocol(Properties props)
    {
    }

    /**
     * Allocates a new JSON Message. 
     * @return Newly allocated JSON Message.
     */
    public JSONMessage allocateMessage()
    {
        return new JSONMessage(StandardCharsets.UTF_8.newEncoder(),
                StandardCharsets.UTF_8.newDecoder());
    }

    /**
     * Gets the message stream for JSON protocol.
     * @return The message stream for JSON protocol.
     */
    public JSONProtocolParser getMessageStream()
    {
        return new JSONProtocolParser(this);
    }

}
